==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property certificates
 * @property enforce
 * @property ports
 * @property validations
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl(
    public val certificates: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlCertificate>,
    public val enforce: Boolean,
    public val ports: List<Int>,
    public val validations: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl):
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl(
                certificates = javaType.certificates().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlCertificate.Companion.toKotlin(args0)
                    })
                }),
                enforce = javaType.enforce(),
                ports = javaType.ports().map({ args0 -> args0 }),
                validations = javaType.validations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property certificates
 * @property enforce
 * @property ports
 * @property validations
 */
public data class GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl(
    public val certificates: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlCertificate>,
    public val enforce: Boolean,
    public val ports: List<Int>,
    public val validations: List<GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl): GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl =
            GetVirtualNodeSpecBackendVirtualServiceClientPolicyTl(
                certificates = javaType.certificates().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlCertificate.Companion.toKotlin(args0)
                    })
                }),
                enforce = javaType.enforce(),
                ports = javaType.ports().map({ args0 -> args0 }),
                validations = javaType.validations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecBackendVirtualServiceClientPolicyTlValidation.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
